@@ -54,6 +54,7 @@ GST_START_TEST (test_change_object_start_stop_in_current_stack)
   gst_element_set_state (comp, GST_STATE_READY);
 
   sink = gst_element_factory_make_or_warn ("fakevideosink", "sink");
+  g_object_set (sink, "sync", FALSE, NULL);
   gst_bin_add_many (GST_BIN (pipeline), comp, sink, NULL);
 
   gst_element_link (comp, sink);
@@ -218,6 +219,7 @@ GST_START_TEST (test_remove_last_object)
   gst_element_set_state (GST_ELEMENT (composition), GST_STATE_READY);
 
   fakesink = gst_element_factory_make ("fakeaudiosink", NULL);
+  g_object_set (fakesink, "sync", FALSE, NULL);
   gst_bin_add_many (GST_BIN (pipeline), GST_ELEMENT (composition), fakesink,
       NULL);
   gst_element_link (GST_ELEMENT (composition), fakesink);
@@ -311,6 +313,7 @@ GST_START_TEST (test_dispose_on_commit)
   composition = gst_element_factory_make ("nlecomposition", "composition");
   pipeline = GST_ELEMENT (gst_pipeline_new (NULL));
   fakesink = gst_element_factory_make ("fakevideosink", NULL);
+  g_object_set (fakesink, "sync", FALSE, NULL);
 
   nlesource = gst_element_factory_make ("nlesource", "nlesource1");
   audiotestsrc = gst_element_factory_make ("audiotestsrc", "audiotestsrc1");
@@ -356,6 +359,7 @@ GST_START_TEST (test_simple_audiomixer)
   composition = gst_element_factory_make ("nlecomposition", "composition");
   gst_element_set_state (composition, GST_STATE_READY);
   fakesink = gst_element_factory_make ("fakeaudiosink", NULL);
+  g_object_set (fakesink, "sync", FALSE, NULL);
 
   /* nle_audiomixer */
   nle_audiomixer = gst_element_factory_make ("nleoperation", "nle_audiomixer");
@@ -488,6 +492,7 @@ GST_START_TEST (test_seek_on_nested)
 
   gst_element_set_state (comp, GST_STATE_READY);
   sink = gst_element_factory_make_or_warn ("fakevideosink", "sink");
+  g_object_set (sink, "sync", FALSE, NULL);
   gst_bin_add_many (GST_BIN (pipeline), comp, sink, NULL);
 
   gst_element_link (comp, sink);
@@ -583,6 +588,7 @@ GST_START_TEST (test_error_in_nested_timeline)
 
   gst_element_set_state (comp, GST_STATE_READY);
   sink = gst_element_factory_make_or_warn ("fakevideosink", "sink");
+  g_object_set (sink, "sync", FALSE, NULL);
   gst_bin_add_many (GST_BIN (pipeline), comp, sink, NULL);
 
   gst_element_link (comp, sink);
@@ -669,6 +675,7 @@ GST_START_TEST (test_nest_deep)
 
   gst_element_set_state (comp, GST_STATE_READY);
   sink = gst_element_factory_make_or_warn ("fakevideosink", "sink");
+  g_object_set (sink, "sync", FALSE, NULL);
   gst_bin_add_many (GST_BIN (pipeline), comp, sink, NULL);
 
   gst_element_link (comp, sink);
