@@ -278,16 +278,17 @@ print_keyboard_help (void)
     const gchar *key_help;
   } key_controls[] = {
     {
-    "space", "pause/unpause"}, {
-    "q or ESC", "quit"}, {
-    "\342\206\222", "seek forward"}, {
-    "\342\206\220", "seek backward"}, {
-    "+", "increase playback rate"}, {
-    "-", "decrease playback rate"}, {
-    "t", "enable/disable trick modes"}, {
-    "s", "change subtitle track"}, {
-    "0", "seek to beginning"}, {
-  "k", "show keyboard shortcuts"},};
+        "space", "pause/unpause"}, {
+        "q or ESC", "quit"}, {
+        "\342\206\222", "seek forward"}, {
+        "\342\206\220", "seek backward"}, {
+        "+", "increase playback rate"}, {
+        "-", "decrease playback rate"}, {
+        "t", "enable/disable trick modes"}, {
+        "s", "change subtitle track"}, {
+        "0", "seek to beginning"}, {
+        "k", "show keyboard shortcuts"},
+  };
   guint i, chars_to_pad, desc_len, max_desc_len = 0;
 
   gst_print ("\n\n%s\n\n", "Interactive mode - keyboard controls:");
@@ -311,9 +312,12 @@ static gboolean
 _parse_track_type (const gchar * option_name, const gchar * value,
     GESLauncherParsedOptions * opts, GError ** error)
 {
-  if (!get_flags_from_string (GES_TYPE_TRACK_TYPE, value, &opts->track_types))
+  guint flags = 0;
+
+  if (!get_flags_from_string (GES_TYPE_TRACK_TYPE, value, &flags))
     return FALSE;
 
+  opts->track_types = (GESTrackType) flags;
   return TRUE;
 }
 
@@ -572,11 +576,13 @@ _set_rendering_details (GESLauncher * self)
   gboolean smart_profile = FALSE;
   GESPipelineFlags cmode = ges_pipeline_get_mode (self->priv->pipeline);
   GESProject *proj;
+  gboolean ret = FALSE;
 
   if (cmode & GES_PIPELINE_MODE_RENDER
       || cmode & GES_PIPELINE_MODE_SMART_RENDER) {
     GST_INFO_OBJECT (self, "Rendering settings already set");
-    return TRUE;
+    ret = TRUE;
+    goto done;
   }
 
   proj =
@@ -616,8 +622,10 @@ _set_rendering_details (GESLauncher * self)
         }
       } else {
         prof = parse_encoding_profile (opts->format);
-        if (!prof)
-          g_error ("Invalid format specified: %s", opts->format);
+        if (!prof) {
+          ges_printerr ("Invalid format specified: %s", opts->format);
+          goto done;
+        }
       }
 
       if (!prof) {
@@ -634,7 +642,53 @@ _set_rendering_details (GESLauncher * self)
       if (!prof) {
         ges_printerr ("Could not find any encoding format for %s\n",
             opts->format);
-        return FALSE;
+        goto done;
+      }
+
+      if (opts->container_profile) {
+        GstEncodingProfile *new_prof;
+        GList *tmp;
+
+        if (!(new_prof = parse_encoding_profile (opts->container_profile))) {
+          ges_printerr ("Failed to parse container profile %s",
+              opts->container_profile);
+          gst_object_unref (prof);
+          goto done;
+        }
+
+        if (!GST_IS_ENCODING_CONTAINER_PROFILE (new_prof)) {
+          ges_printerr ("Top level profile should be container profile");
+          gst_object_unref (prof);
+          gst_object_unref (new_prof);
+          goto done;
+        }
+
+        if (gst_encoding_container_profile_get_profiles
+            (GST_ENCODING_CONTAINER_PROFILE (new_prof))) {
+          ges_printerr ("--container-profile cannot contain children profiles");
+          gst_object_unref (prof);
+          gst_object_unref (new_prof);
+          goto done;
+        }
+
+        /* Existing profile is a single-elementary-stream profile, put it in the
+         * new target container profile */
+        if (!GST_IS_ENCODING_CONTAINER_PROFILE (prof)) {
+          gst_encoding_container_profile_add_profile
+              (GST_ENCODING_CONTAINER_PROFILE (new_prof),
+              GST_ENCODING_PROFILE (gst_encoding_profile_ref (prof)));
+        } else {
+          for (tmp = (GList *)
+              gst_encoding_container_profile_get_profiles
+              (GST_ENCODING_CONTAINER_PROFILE (prof)); tmp; tmp = tmp->next) {
+            gst_encoding_container_profile_add_profile
+                (GST_ENCODING_CONTAINER_PROFILE (new_prof),
+                GST_ENCODING_PROFILE (gst_encoding_profile_ref (tmp->data)));
+          }
+        }
+
+        gst_encoding_profile_unref (prof);
+        prof = new_prof;
       }
 
       gst_print ("\nEncoding details:\n");
@@ -662,14 +716,18 @@ _set_rendering_details (GESLauncher * self)
         || !ges_pipeline_set_mode (self->priv->pipeline,
             opts->smartrender ? GES_PIPELINE_MODE_SMART_RENDER :
             GES_PIPELINE_MODE_RENDER)) {
-      return FALSE;
+      goto done;
     }
 
     gst_encoding_profile_unref (prof);
   } else {
     ges_pipeline_set_mode (self->priv->pipeline, GES_PIPELINE_MODE_PREVIEW);
   }
-  return TRUE;
+
+  ret = TRUE;
+
+done:
+  return ret;
 }
 
 static void
@@ -804,6 +862,10 @@ _project_loaded_cb (GESProject * project, GESTimeline * timeline,
   GESLauncherParsedOptions *opts = &self->priv->parsed_options;
   GST_INFO ("Project loaded, playing it");
 
+  if (self->priv->seenerrors) {
+    return;
+  }
+
   if (opts->save_path) {
     gchar *uri;
     GError *error = NULL;
@@ -849,14 +911,25 @@ _project_loaded_cb (GESProject * project, GESTimeline * timeline,
       g_error ("Failed to setup rendering details\n");
   }
 
-  print_timeline (self->priv->timeline);
 
   g_free (project_uri);
 
-  if (!self->priv->seenerrors && opts->needs_set_state &&
-      gst_element_set_state (GST_ELEMENT (self->priv->pipeline),
-          GST_STATE_PLAYING) == GST_STATE_CHANGE_FAILURE) {
-    g_error ("Failed to start the pipeline\n");
+  if (!self->priv->seenerrors && opts->needs_set_state) {
+    ges_timeline_commit (self->priv->timeline);
+    if (gst_element_set_state (GST_ELEMENT (self->priv->pipeline),
+            GST_STATE_READY) == GST_STATE_CHANGE_FAILURE) {
+      g_error ("Failed to start the pipeline\n");
+    }
+
+    /* Printing the pipeline only in READY state as there might be elements
+     * tweaking it in while going to READY */
+    print_timeline (self->priv->timeline);
+    if (gst_element_set_state (GST_ELEMENT (self->priv->pipeline),
+            GST_STATE_PLAYING) == GST_STATE_CHANGE_FAILURE) {
+      g_error ("Failed to start the pipeline\n");
+    }
+  } else {
+    print_timeline (self->priv->timeline);
   }
 }
 
@@ -1277,6 +1350,11 @@ ges_launcher_get_rendering_option_group (GESLauncherParsedOptions * opts)
           "of the rendered output. This will have no effect if no outputuri "
           "has been specified.",
         "<clip-name>"},
+    {"container-profile", 0, 0, G_OPTION_ARG_STRING, &opts->container_profile,
+          "Set a container profile for rendering. Applies after --format, "
+          "--encoding-profile and profile-from, potentially overriding the "
+          "existing top level container profile",
+        "<container-profile>"},
     {"forward-tags", 0, 0, G_OPTION_ARG_NONE, &opts->forward_tags,
           "Forward tags from input files to the output",
         NULL},
@@ -1329,6 +1407,7 @@ ges_launcher_parse_options (GESLauncher * self,
   gboolean owns_ctx = ctx == NULL;
   GESLauncherParsedOptions *opts = &self->priv->parsed_options;
   gchar *prev_videosink = opts->videosink, *prev_audiosink = opts->audiosink;
+
 /*  *INDENT-OFF* */
   GOptionEntry options[] = {
     {"disable-mixing", 0, 0, G_OPTION_ARG_NONE, &opts->disable_mixing,
@@ -1394,6 +1473,10 @@ ges_launcher_parse_options (GESLauncher * self,
           &opts->interactive,
         "Disable interactive control via the keyboard", NULL
     },
+    {"ignore-eos", 0, 0, G_OPTION_ARG_NONE,
+          &opts->ignore_eos,
+        "Ignore EOS.", NULL
+    },
     {NULL}
   };
 /*  *INDENT-ON* */
@@ -1674,6 +1757,7 @@ _finalize (GObject * object)
   g_free (opts->format);
   g_free (opts->encoding_profile);
   g_free (opts->profile_from);
+  g_free (opts->container_profile);
   g_free (opts->videosink);
   g_free (opts->audiosink);
   g_free (opts->video_track_caps);
